@@ -13,7 +13,6 @@ typedef Eo Efl_Generic_Model;
 
 
 #endif
-#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief Generic model that allows any property to be manually set. Also
  * children of the same type can be added and deleted.
@@ -24,11 +23,12 @@ typedef Eo Efl_Generic_Model;
  * It does not model anything in particular and does not affect anything else
  * in the system.
  *
+ * @since 1.23
+ *
  * @ingroup Efl_Generic_Model
  */
 #define EFL_GENERIC_MODEL_CLASS efl_generic_model_class_get()
 
 EWAPI const Efl_Class *efl_generic_model_class_get(void);
-#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
