@@ -11,6 +11,7 @@ typedef Eo Efl_Net_Dialer_Http;
 #ifndef _EFL_NET_DIALER_HTTP_EO_TYPES
 #define _EFL_NET_DIALER_HTTP_EO_TYPES
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Primary HTTP mode
  *
  * @ingroup Efl_Net
@@ -21,9 +22,11 @@ typedef enum
   EFL_NET_DIALER_HTTP_PRIMARY_MODE_DOWNLOAD, /**< HTTP download mode */
   EFL_NET_DIALER_HTTP_PRIMARY_MODE_UPLOAD /**< HTTP upload mode */
 } Efl_Net_Dialer_Http_Primary_Mode;
+#endif /* EFL_BETA_API_SUPPORT */
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief HTTP Dialer (Client).
  *
@@ -47,10 +50,10 @@ typedef enum
  *
  * To enable debugging use EINA_LOG_LEVELS=ecore_con:4 environment variable.
  *
- * If the proxy is NULL (default), then the system proxy will be used. On UNIX
- * that's the environment variable @c http_proxy (or '$all_proxy') is used if
- * the given address doesn't match @c no_proxy patterns. To disable proxy use
- * an empty string. If provided, the proxy must use one of the following
+ * If the proxy is @c NULL (default), then the system proxy will be used. On
+ * UNIX that's the environment variable @c http_proxy (or '$all_proxy') is used
+ * if the given address doesn't match @c no_proxy patterns. To disable proxy
+ * use an empty string. If provided, the proxy must use one of the following
  * protocols:
  *
  * - http://username:password\@proxyserver:port -
@@ -62,8 +65,6 @@ typedef enum
  * socks4a://proxyserver:port (SOCKSv4 and let socks server to resolve domain)
  * - socks4://proxyserver:port (SOCKSv4)
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 #define EFL_NET_DIALER_HTTP_CLASS efl_net_dialer_http_class_get()
@@ -81,8 +82,6 @@ EWAPI const Efl_Class *efl_net_dialer_http_class_get(void);
  * @param[in] obj The object.
  * @param[in] method HTTP method
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_method_set(Eo *obj, const char *method);
@@ -99,8 +98,6 @@ EOAPI void efl_net_dialer_http_method_set(Eo *obj, const char *method);
  *
  * @return HTTP method
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI const char *efl_net_dialer_http_method_get(const Eo *obj);
@@ -112,7 +109,7 @@ EOAPI const char *efl_net_dialer_http_method_get(const Eo *obj);
  *
  * - If @ref EFL_NET_DIALER_HTTP_PRIMARY_MODE_AUTO, then
  * @ref EFL_NET_DIALER_HTTP_PRIMARY_MODE_DOWNLOAD or
- * @ref EFL_NET_DIALER_HTTP_PRIMARY_MODE_UPLOAD will be choosen based on the
+ * @ref EFL_NET_DIALER_HTTP_PRIMARY_MODE_UPLOAD will be chosen based on the
  * @ref efl_net_dialer_http_method_get: if "PUT", then it's upload, otherwise
  * it's download.
  *
@@ -135,8 +132,6 @@ EOAPI const char *efl_net_dialer_http_method_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] primary_mode Primary HTTP mode
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_primary_mode_set(Eo *obj, Efl_Net_Dialer_Http_Primary_Mode primary_mode);
@@ -148,7 +143,7 @@ EOAPI void efl_net_dialer_http_primary_mode_set(Eo *obj, Efl_Net_Dialer_Http_Pri
  *
  * - If @ref EFL_NET_DIALER_HTTP_PRIMARY_MODE_AUTO, then
  * @ref EFL_NET_DIALER_HTTP_PRIMARY_MODE_DOWNLOAD or
- * @ref EFL_NET_DIALER_HTTP_PRIMARY_MODE_UPLOAD will be choosen based on the
+ * @ref EFL_NET_DIALER_HTTP_PRIMARY_MODE_UPLOAD will be chosen based on the
  * @ref efl_net_dialer_http_method_get: if "PUT", then it's upload, otherwise
  * it's download.
  *
@@ -179,8 +174,6 @@ EOAPI void efl_net_dialer_http_primary_mode_set(Eo *obj, Efl_Net_Dialer_Http_Pri
  *
  * @return Primary HTTP mode
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI Efl_Net_Dialer_Http_Primary_Mode efl_net_dialer_http_primary_mode_get(const Eo *obj);
@@ -193,8 +186,6 @@ EOAPI Efl_Net_Dialer_Http_Primary_Mode efl_net_dialer_http_primary_mode_get(cons
  * @param[in] obj The object.
  * @param[in] ser_agent User-agent
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_user_agent_set(Eo *obj, const char *ser_agent);
@@ -208,8 +199,6 @@ EOAPI void efl_net_dialer_http_user_agent_set(Eo *obj, const char *ser_agent);
  *
  * @return User-agent
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI const char *efl_net_dialer_http_user_agent_get(const Eo *obj);
@@ -225,8 +214,6 @@ EOAPI const char *efl_net_dialer_http_user_agent_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] http_version HTTP version
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_version_set(Eo *obj, Efl_Net_Http_Version http_version);
@@ -243,8 +230,6 @@ EOAPI void efl_net_dialer_http_version_set(Eo *obj, Efl_Net_Http_Version http_ve
  *
  * @return HTTP version
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI Efl_Net_Http_Version efl_net_dialer_http_version_get(const Eo *obj);
@@ -261,8 +246,6 @@ EOAPI Efl_Net_Http_Version efl_net_dialer_http_version_get(const Eo *obj);
  * @ref EFL_NET_HTTP_AUTHENTICATION_METHOD_BASIC
  * @param[in] restricted Restrict method
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_authentication_set(Eo *obj, const char *username, const char *password, Efl_Net_Http_Authentication_Method method, Eina_Bool restricted);
@@ -279,8 +262,6 @@ EOAPI void efl_net_dialer_http_authentication_set(Eo *obj, const char *username,
  * @ref EFL_NET_HTTP_AUTHENTICATION_METHOD_BASIC
  * @param[out] restricted Restrict method
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_authentication_get(const Eo *obj, const char **username, const char **password, Efl_Net_Http_Authentication_Method *method, Eina_Bool *restricted);
@@ -294,8 +275,6 @@ EOAPI void efl_net_dialer_http_authentication_get(const Eo *obj, const char **us
  * @param[in] allow_redirects @c true if redirects are followed, @c false
  * otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_allow_redirects_set(Eo *obj, Eina_Bool allow_redirects);
@@ -309,8 +288,6 @@ EOAPI void efl_net_dialer_http_allow_redirects_set(Eo *obj, Eina_Bool allow_redi
  *
  * @return @c true if redirects are followed, @c false otherwise
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI Eina_Bool efl_net_dialer_http_allow_redirects_get(const Eo *obj);
@@ -326,8 +303,6 @@ EOAPI Eina_Bool efl_net_dialer_http_allow_redirects_get(const Eo *obj);
  * @param[in] key Request header key
  * @param[in] value Request header value
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_request_header_add(Eo *obj, const char *key, const char *value);
@@ -338,11 +313,8 @@ EOAPI void efl_net_dialer_http_request_header_add(Eo *obj, const char *key, cons
  * See @ref efl_net_dialer_http_request_header_add
  *
  * This should be called before dialing.
- *
  * @param[in] obj The object.
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_request_headers_clear(Eo *obj);
@@ -354,11 +326,9 @@ EOAPI void efl_net_dialer_http_request_headers_clear(Eo *obj);
  *
  * @return Iterator for request headers
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
-EOAPI Eina_Iterator *efl_net_dialer_http_request_headers_get(Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI Eina_Iterator *efl_net_dialer_http_request_headers_get(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief "Content-Length:" Header used for uploading/sending.
@@ -368,8 +338,6 @@ EOAPI Eina_Iterator *efl_net_dialer_http_request_headers_get(Eo *obj) EINA_WARN_
  * @param[in] obj The object.
  * @param[in] length Length value
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_request_content_length_set(Eo *obj, int64_t length);
@@ -383,8 +351,6 @@ EOAPI void efl_net_dialer_http_request_content_length_set(Eo *obj, int64_t lengt
  *
  * @return Length value
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI int64_t efl_net_dialer_http_request_content_length_get(const Eo *obj);
@@ -398,8 +364,6 @@ EOAPI int64_t efl_net_dialer_http_request_content_length_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] length Length value
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_response_content_length_set(Eo *obj, int64_t length);
@@ -414,8 +378,6 @@ EOAPI void efl_net_dialer_http_response_content_length_set(Eo *obj, int64_t leng
  *
  * @return Length value
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI int64_t efl_net_dialer_http_response_content_length_get(const Eo *obj);
@@ -427,8 +389,6 @@ EOAPI int64_t efl_net_dialer_http_response_content_length_get(const Eo *obj);
  * @param[in] obj The object.
  * @param[in] content_type Content type header string
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_response_content_type_set(Eo *obj, const char *content_type);
@@ -441,8 +401,6 @@ EOAPI void efl_net_dialer_http_response_content_type_set(Eo *obj, const char *co
  *
  * @return Content type header string
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI const char *efl_net_dialer_http_response_content_type_get(const Eo *obj);
@@ -461,8 +419,6 @@ EOAPI const char *efl_net_dialer_http_response_content_type_get(const Eo *obj);
  *
  * @return HTTP status
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI Efl_Net_Http_Status efl_net_dialer_http_response_status_get(const Eo *obj);
@@ -484,11 +440,9 @@ EOAPI Efl_Net_Http_Status efl_net_dialer_http_response_status_get(const Eo *obj)
  *
  * @return Iterator for response headers
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
-EOAPI Eina_Iterator *efl_net_dialer_http_response_headers_get(Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI Eina_Iterator *efl_net_dialer_http_response_headers_get(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Returns an iterator to the key-value pairs for all response headers.
@@ -496,8 +450,8 @@ EOAPI Eina_Iterator *efl_net_dialer_http_response_headers_get(Eo *obj) EINA_WARN
  * Since multiple requests can occur if
  * @ref efl_net_dialer_http_allow_redirects_get is true, then all headers will
  * be accumulated. To know when a new request's been started, check for headers
- * with keys being NULL. The value will be the "HTTP/VERSION RESPONSE" string
- * received from the host, such as:
+ * with keys being @c NULL. The value will be the "HTTP/VERSION RESPONSE"
+ * string received from the host, such as:
  *
  * - key=NULL, value="HTTP/1.1 302 Found" - key="Location",
  * value="http://someredirect.com" - key=NULL, value="HTTP/1.1 200 Ok" -
@@ -514,15 +468,11 @@ EOAPI Eina_Iterator *efl_net_dialer_http_response_headers_get(Eo *obj) EINA_WARN
  *
  * @return Iterator for all response headers
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
-EOAPI Eina_Iterator *efl_net_dialer_http_response_headers_all_get(Eo *obj) EINA_WARN_UNUSED_RESULT;
+EOAPI Eina_Iterator *efl_net_dialer_http_response_headers_all_get(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /** Saves memory by disposing of the received headers
- *
- * @since 1.19
  *
  * @ingroup Efl_Net_Dialer_Http
  */
@@ -535,8 +485,6 @@ EOAPI void efl_net_dialer_http_response_headers_clear(Eo *obj);
  * @param[out] downloaded Downloaded bytes so far
  * @param[out] total Download total in bytes, 0 if unknown
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_progress_download_get(const Eo *obj, uint64_t *downloaded, uint64_t *total);
@@ -548,8 +496,6 @@ EOAPI void efl_net_dialer_http_progress_download_get(const Eo *obj, uint64_t *do
  * @param[out] uploaded Uploaded bytes so far
  * @param[out] total Upload total in bytes, 0 if unknown
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_progress_upload_get(const Eo *obj, uint64_t *uploaded, uint64_t *total);
@@ -578,8 +524,6 @@ EOAPI void efl_net_dialer_http_progress_upload_get(const Eo *obj, uint64_t *uplo
  * @param[in] obj The object.
  * @param[in] path Path to cookie jar
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_cookie_jar_set(Eo *obj, const char *path);
@@ -609,8 +553,6 @@ EOAPI void efl_net_dialer_http_cookie_jar_set(Eo *obj, const char *path);
  *
  * @return Path to cookie jar
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI const char *efl_net_dialer_http_cookie_jar_get(const Eo *obj);
@@ -626,8 +568,6 @@ EOAPI const char *efl_net_dialer_http_cookie_jar_get(const Eo *obj);
  * @param[in] hostname If @c true, in addition to SSL certificate validation
  * the server name will be matched to certificate DNS entries
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_ssl_verify_set(Eo *obj, Eina_Bool peer, Eina_Bool hostname);
@@ -643,8 +583,6 @@ EOAPI void efl_net_dialer_http_ssl_verify_set(Eo *obj, Eina_Bool peer, Eina_Bool
  * @param[out] hostname If @c true, in addition to SSL certificate validation
  * the server name will be matched to certificate DNS entries
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_ssl_verify_get(const Eo *obj, Eina_Bool *peer, Eina_Bool *hostname);
@@ -657,8 +595,6 @@ EOAPI void efl_net_dialer_http_ssl_verify_get(const Eo *obj, Eina_Bool *peer, Ei
  * @param[in] obj The object.
  * @param[in] path Directory or file path to use for Certificate Authority
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_ssl_certificate_authority_set(Eo *obj, const char *path);
@@ -672,8 +608,6 @@ EOAPI void efl_net_dialer_http_ssl_certificate_authority_set(Eo *obj, const char
  *
  * @return Directory or file path to use for Certificate Authority
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI const char *efl_net_dialer_http_ssl_certificate_authority_get(const Eo *obj);
@@ -684,8 +618,6 @@ EOAPI const char *efl_net_dialer_http_ssl_certificate_authority_get(const Eo *ob
  * @param[in] obj The object.
  * @param[in] file File path to use for CRL
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI void efl_net_dialer_http_ssl_certificate_revocation_list_set(Eo *obj, const char *file);
@@ -697,8 +629,6 @@ EOAPI void efl_net_dialer_http_ssl_certificate_revocation_list_set(Eo *obj, cons
  *
  * @return File path to use for CRL
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
 EOAPI const char *efl_net_dialer_http_ssl_certificate_revocation_list_get(const Eo *obj);
@@ -712,11 +642,9 @@ EOAPI const char *efl_net_dialer_http_ssl_certificate_revocation_list_get(const
  *
  * @return Seconds since 1/1/1970
  *
- * @since 1.19
- *
  * @ingroup Efl_Net_Dialer_Http
  */
-EOAPI int64_t efl_net_dialer_http_date_parse(const Eo *obj, const char *str);
+EOAPI int64_t efl_net_dialer_http_date_parse(const char *str);
 
 /**
  * @brief Serializes the given GMT time in seconds since 1/1/1970.
@@ -725,22 +653,20 @@ EOAPI int64_t efl_net_dialer_http_date_parse(const Eo *obj, const char *str);
  *
  * @param[in] epochtime UNIX Epoch time - seconds since 1/1/1970
  *
- * @return Newly allocated null-terminated string on success or NULL on errors
- *
- * @since 1.19
+ * @return Newly allocated null-terminated string on success or @c NULL on
+ * errors
  *
  * @ingroup Efl_Net_Dialer_Http
  */
-EOAPI char *efl_net_dialer_http_date_serialize(const Eo *obj, int64_t epochtime) EINA_WARN_UNUSED_RESULT;
+EOAPI char *efl_net_dialer_http_date_serialize(int64_t epochtime) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 EWAPI extern const Efl_Event_Description _EFL_NET_DIALER_HTTP_EVENT_HEADERS_DONE;
 
 /** Notifies all headers were parsed and are available.
- *
- * @since 1.19
  *
  * @ingroup Efl_Net_Dialer_Http
  */
 #define EFL_NET_DIALER_HTTP_EVENT_HEADERS_DONE (&(_EFL_NET_DIALER_HTTP_EVENT_HEADERS_DONE))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
