@@ -76,6 +76,7 @@ typedef enum
                                               * perform anything. */
 } Efl_Input_Flags;
 
+#ifdef EFL_BETA_API_SUPPORT
 /**
  * @brief How the mouse pointer should be handled by EFL.
  *
@@ -110,7 +111,9 @@ typedef enum
                                                           *
                                                           * @since 1.2 */
 } Efl_Input_Object_Pointer_Mode;
+#endif /* EFL_BETA_API_SUPPORT */
 
+#ifdef EFL_BETA_API_SUPPORT
 /** Keys for the generic values of all events.
  *
  * @since 1.19
@@ -127,9 +130,9 @@ typedef enum
   EFL_INPUT_VALUE_BUTTONS_PRESSED, /**< 32-bit bit mask (unsigned int). Prefer
                                     * the method @c buttons_pressed to read
                                     * this value. Default: 0. */
-  EFL_INPUT_VALUE_TOOL, /**< ID of the finger or tool (eg. pen) that triggered
-                         * this event. Prefer the property @c tool to read this
-                         * value. Default: 0. */
+  EFL_INPUT_VALUE_TOUCH_ID, /**< ID of the finger or tool (eg. pen) that
+                             * triggered this event. Prefer the property
+                             * @c touch_id to read this value. Default: 0. */
   EFL_INPUT_VALUE_X, /**< Absolute X position where this event occurred, in
                       * pixels. Relative to the window. Default: last known
                       * position. This value may be smoothed out or even
@@ -195,6 +198,7 @@ typedef enum
   EFL_INPUT_VALUE_SLIDER /**< Current position of the slider on the tool. Range:
                           * [-1, 1]. Default: 0. */
 } Efl_Input_Value;
+#endif /* EFL_BETA_API_SUPPORT */
 
 /**
  * @brief Key modifiers such as Control, Alt, etc...
