@@ -13,13 +13,19 @@ typedef Eo Evas_Canvas3D_Object;
 
 
 #endif
+#ifdef EFL_BETA_API_SUPPORT
+/** Evas 3D canvas object class
+ *
+ * @ingroup Evas_Canvas3D_Object
+ */
 #define EVAS_CANVAS3D_OBJECT_CLASS evas_canvas3d_object_class_get()
 
-EWAPI const Eo_Class *evas_canvas3d_object_class_get(void);
+EWAPI const Efl_Class *evas_canvas3d_object_class_get(void);
 
 /**
  * @brief Notify the object regarding its  state change.
  *
+ * @param[in] obj The object.
  * @param[in] state State that is changed.
  * @param[in] ref The Object that caused the change.
  *
@@ -27,16 +33,22 @@ EWAPI const Eo_Class *evas_canvas3d_object_class_get(void);
  */
 EOAPI void evas_canvas3d_object_change(Eo *obj, Evas_Canvas3D_State state, Evas_Canvas3D_Object *ref);
 
-/** Returns the type of the object.
+/**
+ * @brief Returns the type of the object.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Object type
  *
  * @ingroup Evas_Canvas3D_Object
  */
 EOAPI Evas_Canvas3D_Object_Type evas_canvas3d_object_type_get(const Eo *obj);
 
 /**
- * @brief Returns the type of the object.
+ * @brief Sets the type of the object.
  *
- * @param[in] type
+ * @param[in] obj The object.
+ * @param[in] type Object type
  *
  * @ingroup Evas_Canvas3D_Object
  */
@@ -45,8 +57,11 @@ EOAPI void evas_canvas3d_object_type_set(Eo *obj, Evas_Canvas3D_Object_Type type
 /**
  * @brief Returns the status of a particular state of the object.
  *
+ * @param[in] obj The object.
  * @param[in] state State whose status is being asked.
  *
+ * @return @c true if the status is dirty, @c false otherwise
+ *
  * @ingroup Evas_Canvas3D_Object
  */
 EOAPI Eina_Bool evas_canvas3d_object_dirty_get(const Eo *obj, Evas_Canvas3D_State state);
@@ -61,6 +76,7 @@ EOAPI void evas_canvas3d_object_update(Eo *obj);
  * @brief Pure virtual update_notify function.
  *
  * Update request for the object.
+ * @param[in] obj The object.
  *
  * @ingroup Evas_Canvas3D_Object
  */
@@ -71,6 +87,7 @@ EOAPI void evas_canvas3d_object_update_notify(Eo *obj);
  *
  * Update request for the object.
  *
+ * @param[in] obj The object.
  * @param[in] state State that is changed.
  * @param[in] ref The Object that caused the change.
  *
@@ -81,6 +98,7 @@ EOAPI void evas_canvas3d_object_change_notify(Eo *obj, Evas_Canvas3D_State state
 /**
  * @brief Pure virtual register samrt callback function.
  *
+ * @param[in] obj The object.
  * @param[in] event Event type.
  * @param[in] data User data.
  *
@@ -91,25 +109,30 @@ EOAPI void evas_canvas3d_object_callback_register(Eo *obj, const char *event, co
 /**
  * @brief Pure virtual unregister smart callback function.
  *
+ * @param[in] obj The object.
  * @param[in] event Event type.
  *
  * @ingroup Evas_Canvas3D_Object
  */
 EOAPI void evas_canvas3d_object_callback_unregister(Eo *obj, const char *event);
 
-EOAPI extern const Eo_Event_Description _EVAS_CANVAS3D_OBJECT_EVENT_CLICKED;
-EOAPI extern const Eo_Event_Description _EVAS_CANVAS3D_OBJECT_EVENT_COLLISION;
+EWAPI extern const Efl_Event_Description _EVAS_CANVAS3D_OBJECT_EVENT_CLICKED;
 
 /** Clicked Event.
+ * @return Evas_Canvas3D_Node *
  *
  * @ingroup Evas_Canvas3D_Object
  */
 #define EVAS_CANVAS3D_OBJECT_EVENT_CLICKED (&(_EVAS_CANVAS3D_OBJECT_EVENT_CLICKED))
 
+EWAPI extern const Efl_Event_Description _EVAS_CANVAS3D_OBJECT_EVENT_COLLISION;
+
 /** Collision Event.
+ * @return Evas_Canvas3D_Node *
  *
  * @ingroup Evas_Canvas3D_Object
  */
 #define EVAS_CANVAS3D_OBJECT_EVENT_COLLISION (&(_EVAS_CANVAS3D_OBJECT_EVENT_COLLISION))
+#endif /* EFL_BETA_API_SUPPORT */
 
 #endif
